@@ -1,8 +1,17 @@
 import os
 import json
+from pathlib import Path
+
+from IPython.display import display, Javascript
 
 pkg_root_dir = os.path.dirname(__file__)
+print(f'pkg_root_dir: {pkg_root_dir}')
 pjoin = lambda *p: os.path.join(pkg_root_dir, *p)
+js_filename = pjoin('js', 'index.js')
+print(f'js_filename: {js_filename}')
+with open(js_filename) as js_file:
+    js_source = js_file.read()
+    display(Javascript(js_source))
 
 data_dirpath = pjoin('data')
 djoin = lambda *p: os.path.join(data_dirpath, *p)
@@ -15,7 +24,3 @@ def get_pkg_data(filename):
     else:
         raise ValueError(f"Unrecognized extension in {path}")
 
-
-from oui.splatter import splatter
-# import oui.multi_time_vis
-# import oui.confusion_chords
